==> apache-devlake-0.21.0-incubating-src.tar.gz: apache-devlake-0.21.0-incubating-src/backend/plugins/gitlab/models/migrationscripts/register.go <==
/*
Licensed to the Apache Software Foundation (ASF) under one or more
contributor license agreements.  See the NOTICE file distributed with
this work for additional information regarding copyright ownership.
The ASF licenses this file to You under the Apache License, Version 2.0
(the "License"); you may not use this file except in compliance with
the License.  You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

package migrationscripts

import (
	"github.com/apache/incubator-devlake/core/plugin"
)

// All return all the migration scripts
func All() []plugin.MigrationScript {
	return []plugin.MigrationScript{
		new(addInitTables),
		new(addGitlabCI),
		new(addPipelineID),
		new(addPipelineProjects),
		new(fixDurationToFloat8),
		new(addTransformationRule20221125),
		new(addStdTypeToIssue221230),
		new(addIsDetailRequired20230210),
		new(addConnectionIdToTransformationRule),
		new(addGitlabCommitAuthorInfo),
		new(addTypeEnvToPipeline),
		new(renameTr2ScopeConfig),
		new(addGitlabIssueAssignee),
		new(addMrCommitSha),
		new(addRawParamTableForScope),
		new(addProjectArchived),
		new(addDeployment),
		new(addEnvNamePattern),
		new(addQueuedDuration20231129),
		new(modifyDeploymentMessageType),
		new(addTimeToGitlabPipelineProject),
		new(modifyDeploymentCommitTitle),
	}
}

==> apache-devlake-1.0.0-incubating-src.tar.gz: apache-devlake-1.0.0-incubating-src/backend/plugins/gitlab/models/migrationscripts/register.go <==
/*
Licensed to the Apache Software Foundation (ASF) under one or more
contributor license agreements.  See the NOTICE file distributed with
this work for additional information regarding copyright ownership.
The ASF licenses this file to You under the Apache License, Version 2.0
(the "License"); you may not use this file except in compliance with
the License.  You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

package migrationscripts

import (
	"github.com/apache/incubator-devlake/core/plugin"
)

// All return all the migration scripts
func All() []plugin.MigrationScript {
	return []plugin.MigrationScript{
		new(addInitTables),
		new(addGitlabCI),
		new(addPipelineID),
		new(addPipelineProjects),
		new(fixDurationToFloat8),
		new(addTransformationRule20221125),
		new(addStdTypeToIssue221230),
		new(addIsDetailRequired20230210),
		new(addConnectionIdToTransformationRule),
		new(addGitlabCommitAuthorInfo),
		new(addTypeEnvToPipeline),
		new(renameTr2ScopeConfig),
		new(addGitlabIssueAssignee),
		new(addMrCommitSha),
		new(addRawParamTableForScope),
		new(addProjectArchived),
		new(addDeployment),
		new(addUserCreationAt20231120),
		new(addEnvNamePattern),
		new(addQueuedDuration20231129),
		new(modifyDeploymentMessageType),
		new(addTimeToGitlabPipelineProject),
		new(modifyDeploymentCommitTitle),
		new(addWebUrlToGitlabPipelineProject),
		new(addGitlabAssignee),
		new(addGitlabAssigneeAndReviewerPrimaryKey),
	}
}
